@@ -40,7 +40,7 @@ public abstract class MapSourceLibrary
 	{
 		_sourceList.add(new OsmMapSource("Mapnik", "http://tile.openstreetmap.org/"));
 		_sourceList.add(new OsmMapSource("Osma", "http://tah.openstreetmap.org/Tiles/tile/"));
-		_sourceList.add(new OsmMapSource("Cyclemap", "http://andy.sandbox.cloudmade.com/tiles/cycle/"));
+		_sourceList.add(new OsmMapSource("Cyclemap", "http://tile.opencyclemap.org/cycle/"));
 		_sourceList.add(new OsmMapSource("Reitkarte", "http://wanderreitkarte.de/hills/",
 			"http://topo2.wanderreitkarte.de/topo/", 18));
 		_sourceList.add(new MffMapSource("Mapsforfree", "http://maps-for-free.com/layer/relief/", "jpg",
